bidict
======
 
Efficient, Pythonic bidirectional map implementation and related functionality.

Status
------

.. image:: https://img.shields.io/pypi/dm/bidict.svg
    :target: https://pypi.python.org/pypi/bidict
    :alt: Downloads per month

.. image:: https://img.shields.io/pypi/v/bidict.svg
    :target: https://pypi.python.org/pypi/bidict
    :alt: Latest release

.. image:: https://readthedocs.org/projects/bidict/badge/
    :target: https://bidict.readthedocs.org/
    :alt: Documentation

.. image:: https://travis-ci.org/jab/bidict.svg?branch=master
    :target: https://travis-ci.org/jab/bidict
    :alt: Build status

.. image:: https://coveralls.io/repos/jab/bidict/badge.svg?branch=master
    :target: https://coveralls.io/r/jab/bidict
    :alt: Test coverage

.. image:: https://www.codacy.com/project/badge/1c5bfb83d2d54d57898d4ede1c9157ee
    :target: https://www.codacy.com/app/jab/bidict
    :alt: Code quality

.. .. image:: https://pypip.in/py_versions/bidict/badge.svg
..     :target: https://pypi.python.org/pypi/bidict
..     :alt: Supported Python versions
..
.. .. image:: https://pypip.in/implementation/bidict/badge.svg
..     :target: https://pypi.python.org/pypi/bidict
..     :alt: Supported Python implementations

.. image:: https://img.shields.io/pypi/l/bidict.svg
    :target: https://raw.githubusercontent.com/jab/bidict/master/LICENSE
    :alt: License

.. image:: https://img.shields.io/badge/Paypal-Buy%20a%20Drink-blue.svg
    :target: https://www.paypal.com/cgi-bin/webscr?cmd=_xclick&business=jab%40math%2ebrown%2eedu&lc=US&item_name=Buy%20a%20drink%20for%20jab&button_subtype=services&currency_code=USD&bn=PP%2dBuyNowBF%3aPaypal%2dBuy%2520a%2520Drink%2dblue%2esvg%3aNonHosted
    :alt: PayPal - Buy a drink

.. image:: https://api.bountysource.com/badge/team?team_id=72966&style=raised
    :target: https://www.bountysource.com/teams/jab
    :alt: Donate via Bountysource

.. image:: https://badges.gitter.im/Join%20Chat.svg
    :alt: Chat
    :target: https://gitter.im/jab/bidict

Installation
------------

``pip install bidict``

Usage
-----

See https://bidict.readthedocs.org.

Participation
-------------

Please feel free to `create an issue <https://github.com/jab/bidict/issues/new>`_
or `join the chat room <https://gitter.im/jab/bidict>`_
if you have any questions, feedback, or just want to say hi /
tell us about your use case.

Check out
`CONTRIBUTING.rst <https://github.com/jab/bidict/blob/master/CONTRIBUTING.rst>`_
for information about contributing.
